@@ -1,3 +1,3 @@
 from .wb_sdata import wb_sdata
 
-__all__ = ("wb_sdata")
\ No newline at end of file
+__all__ = "wb_sdata"
